from setuptools import setup

setup(
    name='kares',
    version='0.8',
    description='A Python module for kares',
    packages=['kares'],
    author='NoBody',
    author_email='your@nobody.com',
    url='https://nobody.com/',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
    ],
)